@@ -719,7 +719,7 @@ class Client(Item):
 
         # Path
         path = "{base_path}/{id}".format(
-            base_bath = self.base_path,
+            base_path = self.base_path,
             id = self.id
         )
 
@@ -852,7 +852,10 @@ class Clients(list):
         self.per_page = int(clients_etree.attrib.get("per_page", "0"))
         self.total = int(clients_etree.attrib.get("total", "0"))
         self.page = int(clients_etree.attrib.get("page", "1"))
-        self.pages = (self.total // self.per_page) + int(bool(self.total % self.per_page))
+        try:
+            self.pages = (self.total // self.per_page) + int(bool(self.total % self.per_page))
+        except ZeroDivisionError:
+            self.pages = 0
 
         # Iterate over all clients
         for client_etree in clients_etree:
@@ -871,6 +874,7 @@ class Clients(list):
                 note = note,
                 invoice_id = invoice_id,
                 tags = tags,
+                order_by = order_by,
 
                 fetch_all = fetch_all,
                 allow_empty_filter = allow_empty_filter,
